<script setup>
import { ref, nextTick } from 'vue';
import { get, post, postBlob, postForm } from '@/utils/request.js'
import { formatMessage } from '@/utils/localeUtils.js';
import { message } from 'ant-design-vue';

const formTable = ref(null);
const submitButton = ref(null);
const isSave = ref(true);
const open = ref(false);
const initFormData = {}
let formData = ref(initFormData);

let treeData = ref(null);

const emit = defineEmits(['tableReload'])

const handleOk = (e) => {
    nextTick(() => {
        setTimeout(() => {
            submitButton.value.$el.click();
        }, 100);
    });
};

const onFinish = values => {
    // console.log('Success:', values);
    open.value = false;
    post(isSave.value ? '/api/tag/save' : '/api/tag/update', formData.value).then((resp) => {
        let result = resp.data;
        if (result.code === 200) {
            message.success(isSave.value ? formatMessage('page.add.success', '新增成功') : formatMessage('page.update.success', '更新成功'));
        } else {
            message.error(result.msg);
        }
        emit('tableReload', 'reload')
        nextTick(() => {
            formTable.value.resetFields()
        })
    })
};
const onFinishFailed = errorInfo => {
    console.log('Failed:', errorInfo);
};

const UserQueryList = ref(null);
UserQuery();
function UserQuery() {
    postForm('/api/user/query', {}).then(resp => {
        let result = resp.data;
        UserQueryList.value = result.data;
    })
}


defineExpose({
    open,
    formData,
    initFormData,
    isSave,
    treeData,
})

</script>

<script>
export default {
    name: '归类管理-edit'
}
</script>

<template>
    <div>
        <a-modal v-model:open="open"
            :title="isSave ? formatMessage('page.add', '添加') : formatMessage('page.edit', '编辑')" @ok="handleOk"
            style="width: 600px;">
            <a-form :model="formData" ref="formTable" name="formTable" :label-col="{ span: 8 }" :wrapper-col="{ span: 16 }"
                style="display: flex;justify-content: space-between;flex-wrap: wrap;" autocomplete="off"
                @finish="onFinish" @finishFailed="onFinishFailed">
                <!-- <a-form-item :label="formatMessage('db.man_tag.uuid', '编号')" name="uuid" style="width: 250px;">
                    <a-input v-model:value="formData.uuid" />
                </a-form-item> -->
                <a-form-item :label="formatMessage('db.man_tag.parentId', '上级菜单')" name="parentId" style="width: 250px;"
                    :rules="[{ required: true, message: '上级菜单不能为空!' }]">
                    <a-tree-select v-model:value="formData.parentId" show-search style="width: 100%"
                        :dropdown-style="{ maxHeight: '400px', overflow: 'auto' }"
                        :placeholder="formatMessage('page.input', '请输入')" allow-clea tree-data-simple-mode
                        :tree-data="treeData" tree-node-filter-prop="name" :field-names="{
                            children: 'children',
                            label: 'name',
                            value: 'id',
                        }">
                        <template #title="{ value: id, name }">
                            {{ name }}
                        </template>
                    </a-tree-select>
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_tag.name', '名称')" name="name" style="width: 250px;">
                    <a-input v-model:value="formData.name" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_tag.flag', '标识')" name="flag" style="width: 250px;">
                    <a-input v-model:value="formData.flag" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_tag.status', '状态')" name="status" style="width: 250px;">
                    <a-select v-model:value="formData.status" :options="[
                        { label: '正常', value: 1 },
                        { label: '禁用', value: 0 },
                    ]">
                    </a-select>
                </a-form-item>
                <!-- <a-form-item :label="formatMessage('db.man_tag.create_time', '添加时间')" name="createTime"
                    style="width: 250px;">
                    <a-date-picker v-model:value="formData.createTime" show-time format="YYYY-MM-DD HH:mm:ss"
                        value-format="YYYY-MM-DD HH:mm:ss" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_tag.create_by', '添加人员')" name="createBy"
                    style="width: 250px;">
                    <a-select v-model:value="formData.createBy" :placeholder="formatMessage('common.select', '请选择')"
                        style="width: 100%" show-search :options="UserQueryList" optionFilterProp="label"
                        optionLabelProp="label">
                    </a-select>
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_tag.update_time', '修改时间')" name="updateTime"
                    style="width: 250px;">
                    <a-date-picker v-model:value="formData.updateTime" show-time format="YYYY-MM-DD HH:mm:ss"
                        value-format="YYYY-MM-DD HH:mm:ss" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_tag.update_by', '修改人员')" name="updateBy"
                    style="width: 250px;">
                    <a-select v-model:value="formData.updateBy" :placeholder="formatMessage('common.select', '请选择')"
                        style="width: 100%" show-search :options="UserQueryList" optionFilterProp="label"
                        optionLabelProp="label">
                    </a-select>
                </a-form-item> -->
                <a-form-item :label="formatMessage('db.man_tag.memo', '备注')" name="memo" style="width: 250px;">
                    <a-input v-model:value="formData.memo" />
                </a-form-item>
                <!-- <a-form-item :label="formatMessage('db.man_tag.parent_id', '父级')" name="parentId"
                    style="width: 250px;">
                    <a-input v-model:value="formData.parentId" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_tag.parent_name', '父级名称')" name="parentName"
                    style="width: 250px;">
                    <a-input v-model:value="formData.parentName" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_tag.path', '关联路径')" name="path" style="width: 250px;">
                    <a-input v-model:value="formData.path" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_tag.path_name', '关联路径名')" name="pathName"
                    style="width: 250px;">
                    <a-input v-model:value="formData.pathName" />
                </a-form-item> -->
                <a-form-item :label="formatMessage('db.man_tag.type', '类型')" name="type" style="width: 250px;">
                    <a-select v-model:value="formData.type" :options="[
                        { label: '其他', value: 0 },
                    ]">
                    </a-select>
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_tag.count', '数量')" name="count" style="width: 250px;">
                    <a-input v-model:value="formData.count" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_tag.level', '等级')" name="level" style="width: 250px;">
                    <a-input v-model:value="formData.level" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_tag.sort', '排序')" name="sort" style="width: 250px;">
                    <a-input v-model:value="formData.sort" />
                </a-form-item>

                <a-form-item>
                    <a-button type="primary" html-type="submit" ref="submitButton"
                        style="visibility: hidden;">Submit</a-button>
                </a-form-item>
            </a-form>
        </a-modal>
    </div>
</template>

<style></style>
